Method: Titlekit::Want#glue_treshold
- Defined in:
- lib/titlekit/want.rb
#glue_treshold(*args) ⇒ Object
For dual+ subtitles the starts and ends of simultaneously occuring subtitles can be micro-adjusted together if their distance is smaller than the glue_treshold. Normally defaults to 0.3
15 16 17 18 19 20 21 22 |
# File 'lib/titlekit/want.rb', line 15 def glue_treshold(*args) if args.empty? return @glue_treshold else @glue_treshold = args[0] return self end end |